==> metadata-viewer-1.9.tar.gz: metadata-viewer-1.9/metadataviewer/dao/model/__init__.py <==
# **************************************************************************
# *
# * Authors: Yunior C. Fonseca Reyna    (cfonseca@cnb.csic.es)
# *
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from abc import abstractmethod
from metadataviewer.model import Page, Table


class IDAO:
    """DAOs interface"""

    @abstractmethod
    def __init__(self, filename: str):
        pass

    @abstractmethod
    def fillPage(self, page: Page, actualColumn: int, orderAsc: bool) -> None:
       pass

    @abstractmethod
    def fillTable(self, table: Table, objectManager) -> None:
        pass

    @abstractmethod
    def getTableNames(self) -> list:
        pass

    @abstractmethod
    def getTableAliases(self) -> dict:
        pass

    @abstractmethod
    def sort(self, tableName, column, reverse=True) -> None:
        pass

    @staticmethod
    @abstractmethod
    def getCompatibleFileTypes() -> list:
        pass

    @abstractmethod
    def getTableRowCount(self, tableName: str) -> int:
        pass

    @abstractmethod
    def getTableWithAdditionalInfo(self):
        pass

    @abstractmethod
    def getSelectedRangeRowsIds(self, tableName, startRow, numberOfRows, column, reverse=True) -> list:
        pass

==> metadata-viewer-2.0.tar.gz: metadata-viewer-2.0/metadataviewer/dao/model/__init__.py <==
# **************************************************************************
# *
# * Authors: Yunior C. Fonseca Reyna    (cfonseca@cnb.csic.es)
# *
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from abc import abstractmethod
from metadataviewer.model import Page, Table, Column


class IDAO:
    """DAOs interface"""

    @abstractmethod
    def __init__(self, filename: str):
        pass

    @abstractmethod
    def fillPage(self, page: Page, actualColumn: str, orderAsc: bool) -> None:
       pass

    @abstractmethod
    def fillTable(self, table: Table, objectManager) -> None:
        pass

    @abstractmethod
    def getTables(self) -> list:
        pass

    @classmethod
    @abstractmethod
    def getCompatibleFileTypes(cls) -> list:
        pass

    @abstractmethod
    def getTableRowCount(self, tableName: str) -> int:
        pass

    @abstractmethod
    def getTableWithAdditionalInfo(self):
        pass

    @abstractmethod
    def getSelectedRangeRowsIds(self, tableName, startRow, numberOfRows, column, reverse=True) -> list:
        pass

    @abstractmethod
    def getColumnsValues(self, tableName, columns, xAxis, selection, limit,
                         useSelection, reverse=True):
        pass
